pub struct Proxy(_);Trait Implementations
sourceimpl S3 for Proxy
impl S3 for Proxy
sourcefn abort_multipart_upload<'life0, 'async_trait>(
&'life0 self,
input: AbortMultipartUploadInput
) -> Pin<Box<dyn Future<Output = S3Result<AbortMultipartUploadOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn abort_multipart_upload<'life0, 'async_trait>( &'life0 self, input: AbortMultipartUploadInput ) -> Pin<Box<dyn Future<Output = S3Result<AbortMultipartUploadOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action aborts a multipart upload. After a multipart upload is aborted, no
sourcefn complete_multipart_upload<'life0, 'async_trait>(
&'life0 self,
input: CompleteMultipartUploadInput
) -> Pin<Box<dyn Future<Output = S3Result<CompleteMultipartUploadOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn complete_multipart_upload<'life0, 'async_trait>( &'life0 self, input: CompleteMultipartUploadInput ) -> Pin<Box<dyn Future<Output = S3Result<CompleteMultipartUploadOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Completes a multipart upload by assembling previously uploaded parts.
sourcefn copy_object<'life0, 'async_trait>(
&'life0 self,
input: CopyObjectInput
) -> Pin<Box<dyn Future<Output = S3Result<CopyObjectOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn copy_object<'life0, 'async_trait>( &'life0 self, input: CopyObjectInput ) -> Pin<Box<dyn Future<Output = S3Result<CopyObjectOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Creates a copy of an object that is already stored in Amazon S3.
sourcefn create_bucket<'life0, 'async_trait>(
&'life0 self,
input: CreateBucketInput
) -> Pin<Box<dyn Future<Output = S3Result<CreateBucketOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_bucket<'life0, 'async_trait>( &'life0 self, input: CreateBucketInput ) -> Pin<Box<dyn Future<Output = S3Result<CreateBucketOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Creates a new S3 bucket. To create a bucket, you must register with Amazon S3 and have a
sourcefn create_multipart_upload<'life0, 'async_trait>(
&'life0 self,
input: CreateMultipartUploadInput
) -> Pin<Box<dyn Future<Output = S3Result<CreateMultipartUploadOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_multipart_upload<'life0, 'async_trait>( &'life0 self, input: CreateMultipartUploadInput ) -> Pin<Box<dyn Future<Output = S3Result<CreateMultipartUploadOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action initiates a multipart upload and returns an upload ID. This upload ID is
sourcefn delete_bucket<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket<'life0, 'async_trait>( &'life0 self, input: DeleteBucketInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes the S3 bucket. All objects (including all object versions and delete markers) in
sourcefn delete_bucket_analytics_configuration<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketAnalyticsConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketAnalyticsConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_analytics_configuration<'life0, 'async_trait>( &'life0 self, input: DeleteBucketAnalyticsConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketAnalyticsConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes an analytics configuration for the bucket (specified by the analytics
sourcefn delete_bucket_cors<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketCorsInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketCorsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_cors<'life0, 'async_trait>( &'life0 self, input: DeleteBucketCorsInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketCorsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes the cors configuration information set for the bucket.
sourcefn delete_bucket_encryption<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketEncryptionInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketEncryptionOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_encryption<'life0, 'async_trait>( &'life0 self, input: DeleteBucketEncryptionInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketEncryptionOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This implementation of the DELETE action removes default encryption from the bucket.
sourcefn delete_bucket_intelligent_tiering_configuration<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketIntelligentTieringConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketIntelligentTieringConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_intelligent_tiering_configuration<'life0, 'async_trait>( &'life0 self, input: DeleteBucketIntelligentTieringConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketIntelligentTieringConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes the S3 Intelligent-Tiering configuration from the specified bucket.
sourcefn delete_bucket_inventory_configuration<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketInventoryConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketInventoryConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_inventory_configuration<'life0, 'async_trait>( &'life0 self, input: DeleteBucketInventoryConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketInventoryConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes an inventory configuration (identified by the inventory ID) from the
sourcefn delete_bucket_lifecycle<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketLifecycleInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketLifecycleOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_lifecycle<'life0, 'async_trait>( &'life0 self, input: DeleteBucketLifecycleInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketLifecycleOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes the lifecycle configuration from the specified bucket. Amazon S3 removes all the
sourcefn delete_bucket_metrics_configuration<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketMetricsConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketMetricsConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_metrics_configuration<'life0, 'async_trait>( &'life0 self, input: DeleteBucketMetricsConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketMetricsConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes a metrics configuration for the Amazon CloudWatch request metrics (specified by the
sourcefn delete_bucket_ownership_controls<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketOwnershipControlsInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketOwnershipControlsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_ownership_controls<'life0, 'async_trait>( &'life0 self, input: DeleteBucketOwnershipControlsInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketOwnershipControlsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Removes OwnershipControls for an Amazon S3 bucket. To use this operation, you
sourcefn delete_bucket_policy<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketPolicyInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketPolicyOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_policy<'life0, 'async_trait>( &'life0 self, input: DeleteBucketPolicyInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketPolicyOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This implementation of the DELETE action uses the policy subresource to delete the
sourcefn delete_bucket_replication<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketReplicationInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketReplicationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_replication<'life0, 'async_trait>( &'life0 self, input: DeleteBucketReplicationInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketReplicationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes the replication configuration from the bucket.
sourcefn delete_bucket_tagging<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketTaggingInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketTaggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_tagging<'life0, 'async_trait>( &'life0 self, input: DeleteBucketTaggingInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketTaggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Deletes the tags from the bucket.
sourcefn delete_bucket_website<'life0, 'async_trait>(
&'life0 self,
input: DeleteBucketWebsiteInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketWebsiteOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_bucket_website<'life0, 'async_trait>( &'life0 self, input: DeleteBucketWebsiteInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteBucketWebsiteOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action removes the website configuration for a bucket. Amazon S3 returns a 200
sourcefn delete_object<'life0, 'async_trait>(
&'life0 self,
input: DeleteObjectInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteObjectOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_object<'life0, 'async_trait>( &'life0 self, input: DeleteObjectInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteObjectOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Removes the null version (if there is one) of an object and inserts a delete marker,
sourcefn delete_object_tagging<'life0, 'async_trait>(
&'life0 self,
input: DeleteObjectTaggingInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteObjectTaggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_object_tagging<'life0, 'async_trait>( &'life0 self, input: DeleteObjectTaggingInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteObjectTaggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Removes the entire tag set from the specified object. For more information about
sourcefn delete_objects<'life0, 'async_trait>(
&'life0 self,
input: DeleteObjectsInput
) -> Pin<Box<dyn Future<Output = S3Result<DeleteObjectsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_objects<'life0, 'async_trait>( &'life0 self, input: DeleteObjectsInput ) -> Pin<Box<dyn Future<Output = S3Result<DeleteObjectsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action enables you to delete multiple objects from a bucket using a single HTTP
sourcefn delete_public_access_block<'life0, 'async_trait>(
&'life0 self,
input: DeletePublicAccessBlockInput
) -> Pin<Box<dyn Future<Output = S3Result<DeletePublicAccessBlockOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_public_access_block<'life0, 'async_trait>( &'life0 self, input: DeletePublicAccessBlockInput ) -> Pin<Box<dyn Future<Output = S3Result<DeletePublicAccessBlockOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Removes the PublicAccessBlock configuration for an Amazon S3 bucket. To use this
sourcefn get_bucket_accelerate_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetBucketAccelerateConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketAccelerateConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_accelerate_configuration<'life0, 'async_trait>( &'life0 self, input: GetBucketAccelerateConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketAccelerateConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This implementation of the GET action uses the accelerate subresource to
sourcefn get_bucket_acl<'life0, 'async_trait>(
&'life0 self,
input: GetBucketAclInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketAclOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_acl<'life0, 'async_trait>( &'life0 self, input: GetBucketAclInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketAclOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This implementation of the GET action uses the acl
sourcefn get_bucket_analytics_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetBucketAnalyticsConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketAnalyticsConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_analytics_configuration<'life0, 'async_trait>( &'life0 self, input: GetBucketAnalyticsConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketAnalyticsConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This implementation of the GET action returns an analytics configuration (identified
sourcefn get_bucket_cors<'life0, 'async_trait>(
&'life0 self,
input: GetBucketCorsInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketCorsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_cors<'life0, 'async_trait>( &'life0 self, input: GetBucketCorsInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketCorsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the Cross-Origin Resource Sharing (CORS) configuration information set for the
sourcefn get_bucket_encryption<'life0, 'async_trait>(
&'life0 self,
input: GetBucketEncryptionInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketEncryptionOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_encryption<'life0, 'async_trait>( &'life0 self, input: GetBucketEncryptionInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketEncryptionOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the default encryption configuration for an Amazon S3 bucket. If the bucket does not
sourcefn get_bucket_intelligent_tiering_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetBucketIntelligentTieringConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketIntelligentTieringConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_intelligent_tiering_configuration<'life0, 'async_trait>( &'life0 self, input: GetBucketIntelligentTieringConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketIntelligentTieringConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Gets the S3 Intelligent-Tiering configuration from the specified bucket.
sourcefn get_bucket_inventory_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetBucketInventoryConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketInventoryConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_inventory_configuration<'life0, 'async_trait>( &'life0 self, input: GetBucketInventoryConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketInventoryConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns an inventory configuration (identified by the inventory configuration ID) from
sourcefn get_bucket_lifecycle_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetBucketLifecycleConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketLifecycleConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_lifecycle_configuration<'life0, 'async_trait>( &'life0 self, input: GetBucketLifecycleConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketLifecycleConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
sourcefn get_bucket_location<'life0, 'async_trait>(
&'life0 self,
input: GetBucketLocationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketLocationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_location<'life0, 'async_trait>( &'life0 self, input: GetBucketLocationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketLocationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the Region the bucket resides in. You set the bucket's Region using the
sourcefn get_bucket_logging<'life0, 'async_trait>(
&'life0 self,
input: GetBucketLoggingInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketLoggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_logging<'life0, 'async_trait>( &'life0 self, input: GetBucketLoggingInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketLoggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the logging status of a bucket and the permissions users have to view and modify
sourcefn get_bucket_metrics_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetBucketMetricsConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketMetricsConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_metrics_configuration<'life0, 'async_trait>( &'life0 self, input: GetBucketMetricsConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketMetricsConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Gets a metrics configuration (specified by the metrics configuration ID) from the
sourcefn get_bucket_notification_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetBucketNotificationConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketNotificationConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_notification_configuration<'life0, 'async_trait>( &'life0 self, input: GetBucketNotificationConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketNotificationConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the notification configuration of a bucket.
sourcefn get_bucket_ownership_controls<'life0, 'async_trait>(
&'life0 self,
input: GetBucketOwnershipControlsInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketOwnershipControlsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_ownership_controls<'life0, 'async_trait>( &'life0 self, input: GetBucketOwnershipControlsInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketOwnershipControlsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Retrieves OwnershipControls for an Amazon S3 bucket. To use this operation, you
sourcefn get_bucket_policy<'life0, 'async_trait>(
&'life0 self,
input: GetBucketPolicyInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketPolicyOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_policy<'life0, 'async_trait>( &'life0 self, input: GetBucketPolicyInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketPolicyOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the policy of a specified bucket. If you are using an identity other than the
sourcefn get_bucket_policy_status<'life0, 'async_trait>(
&'life0 self,
input: GetBucketPolicyStatusInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketPolicyStatusOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_policy_status<'life0, 'async_trait>( &'life0 self, input: GetBucketPolicyStatusInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketPolicyStatusOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Retrieves the policy status for an Amazon S3 bucket, indicating whether the bucket is public.
sourcefn get_bucket_replication<'life0, 'async_trait>(
&'life0 self,
input: GetBucketReplicationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketReplicationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_replication<'life0, 'async_trait>( &'life0 self, input: GetBucketReplicationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketReplicationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the replication configuration of a bucket.
sourcefn get_bucket_request_payment<'life0, 'async_trait>(
&'life0 self,
input: GetBucketRequestPaymentInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketRequestPaymentOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_request_payment<'life0, 'async_trait>( &'life0 self, input: GetBucketRequestPaymentInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketRequestPaymentOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the request payment configuration of a bucket. To use this version of the
sourcefn get_bucket_tagging<'life0, 'async_trait>(
&'life0 self,
input: GetBucketTaggingInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketTaggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_tagging<'life0, 'async_trait>( &'life0 self, input: GetBucketTaggingInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketTaggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the tag set associated with the bucket.
sourcefn get_bucket_versioning<'life0, 'async_trait>(
&'life0 self,
input: GetBucketVersioningInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketVersioningOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_versioning<'life0, 'async_trait>( &'life0 self, input: GetBucketVersioningInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketVersioningOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the versioning state of a bucket.
sourcefn get_bucket_website<'life0, 'async_trait>(
&'life0 self,
input: GetBucketWebsiteInput
) -> Pin<Box<dyn Future<Output = S3Result<GetBucketWebsiteOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_bucket_website<'life0, 'async_trait>( &'life0 self, input: GetBucketWebsiteInput ) -> Pin<Box<dyn Future<Output = S3Result<GetBucketWebsiteOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the website configuration for a bucket. To host website on Amazon S3, you can
sourcefn get_object<'life0, 'async_trait>(
&'life0 self,
input: GetObjectInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object<'life0, 'async_trait>( &'life0 self, input: GetObjectInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Retrieves objects from Amazon S3. To use GET, you must have READ
sourcefn get_object_acl<'life0, 'async_trait>(
&'life0 self,
input: GetObjectAclInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectAclOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object_acl<'life0, 'async_trait>( &'life0 self, input: GetObjectAclInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectAclOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the access control list (ACL) of an object. To use this operation, you must have
sourcefn get_object_attributes<'life0, 'async_trait>(
&'life0 self,
input: GetObjectAttributesInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectAttributesOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object_attributes<'life0, 'async_trait>( &'life0 self, input: GetObjectAttributesInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectAttributesOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Retrieves all the metadata from an object without returning the object itself. This
sourcefn get_object_legal_hold<'life0, 'async_trait>(
&'life0 self,
input: GetObjectLegalHoldInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectLegalHoldOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object_legal_hold<'life0, 'async_trait>( &'life0 self, input: GetObjectLegalHoldInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectLegalHoldOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Gets an object's current legal hold status. For more information, see Locking
sourcefn get_object_lock_configuration<'life0, 'async_trait>(
&'life0 self,
input: GetObjectLockConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectLockConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object_lock_configuration<'life0, 'async_trait>( &'life0 self, input: GetObjectLockConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectLockConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Gets the Object Lock configuration for a bucket. The rule specified in the Object Lock
sourcefn get_object_retention<'life0, 'async_trait>(
&'life0 self,
input: GetObjectRetentionInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectRetentionOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object_retention<'life0, 'async_trait>( &'life0 self, input: GetObjectRetentionInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectRetentionOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Retrieves an object's retention settings. For more information, see Locking Objects.
sourcefn get_object_tagging<'life0, 'async_trait>(
&'life0 self,
input: GetObjectTaggingInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectTaggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object_tagging<'life0, 'async_trait>( &'life0 self, input: GetObjectTaggingInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectTaggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns the tag-set of an object. You send the GET request against the tagging
sourcefn get_object_torrent<'life0, 'async_trait>(
&'life0 self,
input: GetObjectTorrentInput
) -> Pin<Box<dyn Future<Output = S3Result<GetObjectTorrentOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_object_torrent<'life0, 'async_trait>( &'life0 self, input: GetObjectTorrentInput ) -> Pin<Box<dyn Future<Output = S3Result<GetObjectTorrentOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns torrent files from a bucket. BitTorrent can save you bandwidth when you're
sourcefn get_public_access_block<'life0, 'async_trait>(
&'life0 self,
input: GetPublicAccessBlockInput
) -> Pin<Box<dyn Future<Output = S3Result<GetPublicAccessBlockOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_public_access_block<'life0, 'async_trait>( &'life0 self, input: GetPublicAccessBlockInput ) -> Pin<Box<dyn Future<Output = S3Result<GetPublicAccessBlockOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Retrieves the PublicAccessBlock configuration for an Amazon S3 bucket. To use
sourcefn head_bucket<'life0, 'async_trait>(
&'life0 self,
input: HeadBucketInput
) -> Pin<Box<dyn Future<Output = S3Result<HeadBucketOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn head_bucket<'life0, 'async_trait>( &'life0 self, input: HeadBucketInput ) -> Pin<Box<dyn Future<Output = S3Result<HeadBucketOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action is useful to determine if a bucket exists and you have permission to
sourcefn head_object<'life0, 'async_trait>(
&'life0 self,
input: HeadObjectInput
) -> Pin<Box<dyn Future<Output = S3Result<HeadObjectOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn head_object<'life0, 'async_trait>( &'life0 self, input: HeadObjectInput ) -> Pin<Box<dyn Future<Output = S3Result<HeadObjectOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
The HEAD action retrieves metadata from an object without returning the object
sourcefn list_bucket_analytics_configurations<'life0, 'async_trait>(
&'life0 self,
input: ListBucketAnalyticsConfigurationsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListBucketAnalyticsConfigurationsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_bucket_analytics_configurations<'life0, 'async_trait>( &'life0 self, input: ListBucketAnalyticsConfigurationsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListBucketAnalyticsConfigurationsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Lists the analytics configurations for the bucket. You can have up to 1,000 analytics
sourcefn list_bucket_intelligent_tiering_configurations<'life0, 'async_trait>(
&'life0 self,
input: ListBucketIntelligentTieringConfigurationsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListBucketIntelligentTieringConfigurationsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_bucket_intelligent_tiering_configurations<'life0, 'async_trait>( &'life0 self, input: ListBucketIntelligentTieringConfigurationsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListBucketIntelligentTieringConfigurationsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Lists the S3 Intelligent-Tiering configuration from the specified bucket.
sourcefn list_bucket_inventory_configurations<'life0, 'async_trait>(
&'life0 self,
input: ListBucketInventoryConfigurationsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListBucketInventoryConfigurationsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_bucket_inventory_configurations<'life0, 'async_trait>( &'life0 self, input: ListBucketInventoryConfigurationsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListBucketInventoryConfigurationsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns a list of inventory configurations for the bucket. You can have up to 1,000
sourcefn list_bucket_metrics_configurations<'life0, 'async_trait>(
&'life0 self,
input: ListBucketMetricsConfigurationsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListBucketMetricsConfigurationsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_bucket_metrics_configurations<'life0, 'async_trait>( &'life0 self, input: ListBucketMetricsConfigurationsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListBucketMetricsConfigurationsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Lists the metrics configurations for the bucket. The metrics configurations are only for
sourcefn list_buckets<'life0, 'async_trait>(
&'life0 self,
input: ListBucketsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListBucketsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_buckets<'life0, 'async_trait>( &'life0 self, input: ListBucketsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListBucketsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns a list of all buckets owned by the authenticated sender of the request. To use
sourcefn list_multipart_uploads<'life0, 'async_trait>(
&'life0 self,
input: ListMultipartUploadsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListMultipartUploadsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_multipart_uploads<'life0, 'async_trait>( &'life0 self, input: ListMultipartUploadsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListMultipartUploadsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action lists in-progress multipart uploads. An in-progress multipart upload is a
sourcefn list_object_versions<'life0, 'async_trait>(
&'life0 self,
input: ListObjectVersionsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListObjectVersionsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_object_versions<'life0, 'async_trait>( &'life0 self, input: ListObjectVersionsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListObjectVersionsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns metadata about all versions of the objects in a bucket. You can also use request
sourcefn list_objects<'life0, 'async_trait>(
&'life0 self,
input: ListObjectsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListObjectsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_objects<'life0, 'async_trait>( &'life0 self, input: ListObjectsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListObjectsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns some or all (up to 1,000) of the objects in a bucket. You can use the request
sourcefn list_objects_v2<'life0, 'async_trait>(
&'life0 self,
input: ListObjectsV2Input
) -> Pin<Box<dyn Future<Output = S3Result<ListObjectsV2Output>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_objects_v2<'life0, 'async_trait>( &'life0 self, input: ListObjectsV2Input ) -> Pin<Box<dyn Future<Output = S3Result<ListObjectsV2Output>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Returns some or all (up to 1,000) of the objects in a bucket with each request. You can use
sourcefn list_parts<'life0, 'async_trait>(
&'life0 self,
input: ListPartsInput
) -> Pin<Box<dyn Future<Output = S3Result<ListPartsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_parts<'life0, 'async_trait>( &'life0 self, input: ListPartsInput ) -> Pin<Box<dyn Future<Output = S3Result<ListPartsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Lists the parts that have been uploaded for a specific multipart upload. This operation
sourcefn put_bucket_accelerate_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutBucketAccelerateConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketAccelerateConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_accelerate_configuration<'life0, 'async_trait>( &'life0 self, input: PutBucketAccelerateConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketAccelerateConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the accelerate configuration of an existing bucket. Amazon S3 Transfer Acceleration is a
sourcefn put_bucket_acl<'life0, 'async_trait>(
&'life0 self,
input: PutBucketAclInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketAclOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_acl<'life0, 'async_trait>( &'life0 self, input: PutBucketAclInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketAclOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the permissions on an existing bucket using access control lists (ACL). For more
sourcefn put_bucket_analytics_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutBucketAnalyticsConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketAnalyticsConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_analytics_configuration<'life0, 'async_trait>( &'life0 self, input: PutBucketAnalyticsConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketAnalyticsConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets an analytics configuration for the bucket (specified by the analytics configuration
sourcefn put_bucket_cors<'life0, 'async_trait>(
&'life0 self,
input: PutBucketCorsInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketCorsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_cors<'life0, 'async_trait>( &'life0 self, input: PutBucketCorsInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketCorsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the cors configuration for your bucket. If the configuration exists,
sourcefn put_bucket_encryption<'life0, 'async_trait>(
&'life0 self,
input: PutBucketEncryptionInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketEncryptionOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_encryption<'life0, 'async_trait>( &'life0 self, input: PutBucketEncryptionInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketEncryptionOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action uses the encryption subresource to configure default
sourcefn put_bucket_intelligent_tiering_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutBucketIntelligentTieringConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketIntelligentTieringConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_intelligent_tiering_configuration<'life0, 'async_trait>( &'life0 self, input: PutBucketIntelligentTieringConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketIntelligentTieringConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Puts a S3 Intelligent-Tiering configuration to the specified bucket.
sourcefn put_bucket_inventory_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutBucketInventoryConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketInventoryConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_inventory_configuration<'life0, 'async_trait>( &'life0 self, input: PutBucketInventoryConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketInventoryConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This implementation of the PUT action adds an inventory configuration
sourcefn put_bucket_lifecycle_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutBucketLifecycleConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketLifecycleConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_lifecycle_configuration<'life0, 'async_trait>( &'life0 self, input: PutBucketLifecycleConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketLifecycleConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Creates a new lifecycle configuration for the bucket or replaces an existing lifecycle
sourcefn put_bucket_logging<'life0, 'async_trait>(
&'life0 self,
input: PutBucketLoggingInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketLoggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_logging<'life0, 'async_trait>( &'life0 self, input: PutBucketLoggingInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketLoggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Set the logging parameters for a bucket and to specify permissions for who can view and
sourcefn put_bucket_metrics_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutBucketMetricsConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketMetricsConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_metrics_configuration<'life0, 'async_trait>( &'life0 self, input: PutBucketMetricsConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketMetricsConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets a metrics configuration (specified by the metrics configuration ID) for the bucket.
sourcefn put_bucket_notification_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutBucketNotificationConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketNotificationConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_notification_configuration<'life0, 'async_trait>( &'life0 self, input: PutBucketNotificationConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketNotificationConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Enables notifications of specified events for a bucket. For more information about event
sourcefn put_bucket_ownership_controls<'life0, 'async_trait>(
&'life0 self,
input: PutBucketOwnershipControlsInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketOwnershipControlsOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_ownership_controls<'life0, 'async_trait>( &'life0 self, input: PutBucketOwnershipControlsInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketOwnershipControlsOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Creates or modifies OwnershipControls for an Amazon S3 bucket. To use this
sourcefn put_bucket_policy<'life0, 'async_trait>(
&'life0 self,
input: PutBucketPolicyInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketPolicyOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_policy<'life0, 'async_trait>( &'life0 self, input: PutBucketPolicyInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketPolicyOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Applies an Amazon S3 bucket policy to an Amazon S3 bucket. If you are using an identity other than
sourcefn put_bucket_replication<'life0, 'async_trait>(
&'life0 self,
input: PutBucketReplicationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketReplicationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_replication<'life0, 'async_trait>( &'life0 self, input: PutBucketReplicationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketReplicationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Creates a replication configuration or replaces an existing one. For more information,
sourcefn put_bucket_request_payment<'life0, 'async_trait>(
&'life0 self,
input: PutBucketRequestPaymentInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketRequestPaymentOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_request_payment<'life0, 'async_trait>( &'life0 self, input: PutBucketRequestPaymentInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketRequestPaymentOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the request payment configuration for a bucket. By default, the bucket owner pays
sourcefn put_bucket_tagging<'life0, 'async_trait>(
&'life0 self,
input: PutBucketTaggingInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketTaggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_tagging<'life0, 'async_trait>( &'life0 self, input: PutBucketTaggingInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketTaggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the tags for a bucket.
sourcefn put_bucket_versioning<'life0, 'async_trait>(
&'life0 self,
input: PutBucketVersioningInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketVersioningOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_versioning<'life0, 'async_trait>( &'life0 self, input: PutBucketVersioningInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketVersioningOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the versioning state of an existing bucket.
sourcefn put_bucket_website<'life0, 'async_trait>(
&'life0 self,
input: PutBucketWebsiteInput
) -> Pin<Box<dyn Future<Output = S3Result<PutBucketWebsiteOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_bucket_website<'life0, 'async_trait>( &'life0 self, input: PutBucketWebsiteInput ) -> Pin<Box<dyn Future<Output = S3Result<PutBucketWebsiteOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the configuration of the website that is specified in the website
sourcefn put_object<'life0, 'async_trait>(
&'life0 self,
input: PutObjectInput
) -> Pin<Box<dyn Future<Output = S3Result<PutObjectOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_object<'life0, 'async_trait>( &'life0 self, input: PutObjectInput ) -> Pin<Box<dyn Future<Output = S3Result<PutObjectOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Adds an object to a bucket. You must have WRITE permissions on a bucket to add an object
sourcefn put_object_acl<'life0, 'async_trait>(
&'life0 self,
input: PutObjectAclInput
) -> Pin<Box<dyn Future<Output = S3Result<PutObjectAclOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_object_acl<'life0, 'async_trait>( &'life0 self, input: PutObjectAclInput ) -> Pin<Box<dyn Future<Output = S3Result<PutObjectAclOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Uses the acl subresource to set the access control list (ACL) permissions
sourcefn put_object_legal_hold<'life0, 'async_trait>(
&'life0 self,
input: PutObjectLegalHoldInput
) -> Pin<Box<dyn Future<Output = S3Result<PutObjectLegalHoldOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_object_legal_hold<'life0, 'async_trait>( &'life0 self, input: PutObjectLegalHoldInput ) -> Pin<Box<dyn Future<Output = S3Result<PutObjectLegalHoldOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Applies a legal hold configuration to the specified object. For more information, see
sourcefn put_object_lock_configuration<'life0, 'async_trait>(
&'life0 self,
input: PutObjectLockConfigurationInput
) -> Pin<Box<dyn Future<Output = S3Result<PutObjectLockConfigurationOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_object_lock_configuration<'life0, 'async_trait>( &'life0 self, input: PutObjectLockConfigurationInput ) -> Pin<Box<dyn Future<Output = S3Result<PutObjectLockConfigurationOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Places an Object Lock configuration on the specified bucket. The rule specified in the
sourcefn put_object_retention<'life0, 'async_trait>(
&'life0 self,
input: PutObjectRetentionInput
) -> Pin<Box<dyn Future<Output = S3Result<PutObjectRetentionOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_object_retention<'life0, 'async_trait>( &'life0 self, input: PutObjectRetentionInput ) -> Pin<Box<dyn Future<Output = S3Result<PutObjectRetentionOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Places an Object Retention configuration on an object. For more information, see Locking Objects.
sourcefn put_object_tagging<'life0, 'async_trait>(
&'life0 self,
input: PutObjectTaggingInput
) -> Pin<Box<dyn Future<Output = S3Result<PutObjectTaggingOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_object_tagging<'life0, 'async_trait>( &'life0 self, input: PutObjectTaggingInput ) -> Pin<Box<dyn Future<Output = S3Result<PutObjectTaggingOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Sets the supplied tag-set to an object that already exists in a bucket.
sourcefn put_public_access_block<'life0, 'async_trait>(
&'life0 self,
input: PutPublicAccessBlockInput
) -> Pin<Box<dyn Future<Output = S3Result<PutPublicAccessBlockOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn put_public_access_block<'life0, 'async_trait>( &'life0 self, input: PutPublicAccessBlockInput ) -> Pin<Box<dyn Future<Output = S3Result<PutPublicAccessBlockOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Creates or modifies the PublicAccessBlock configuration for an Amazon S3 bucket.
sourcefn restore_object<'life0, 'async_trait>(
&'life0 self,
input: RestoreObjectInput
) -> Pin<Box<dyn Future<Output = S3Result<RestoreObjectOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn restore_object<'life0, 'async_trait>( &'life0 self, input: RestoreObjectInput ) -> Pin<Box<dyn Future<Output = S3Result<RestoreObjectOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Restores an archived copy of an object back into Amazon S3
sourcefn select_object_content<'life0, 'async_trait>(
&'life0 self,
input: SelectObjectContentInput
) -> Pin<Box<dyn Future<Output = S3Result<SelectObjectContentOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn select_object_content<'life0, 'async_trait>( &'life0 self, input: SelectObjectContentInput ) -> Pin<Box<dyn Future<Output = S3Result<SelectObjectContentOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
This action filters the contents of an Amazon S3 object based on a simple structured query
sourcefn upload_part<'life0, 'async_trait>(
&'life0 self,
input: UploadPartInput
) -> Pin<Box<dyn Future<Output = S3Result<UploadPartOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn upload_part<'life0, 'async_trait>( &'life0 self, input: UploadPartInput ) -> Pin<Box<dyn Future<Output = S3Result<UploadPartOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Uploads a part in a multipart upload.
sourcefn upload_part_copy<'life0, 'async_trait>(
&'life0 self,
input: UploadPartCopyInput
) -> Pin<Box<dyn Future<Output = S3Result<UploadPartCopyOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn upload_part_copy<'life0, 'async_trait>( &'life0 self, input: UploadPartCopyInput ) -> Pin<Box<dyn Future<Output = S3Result<UploadPartCopyOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Uploads a part by copying data from an existing object as data source. You specify the
sourcefn write_get_object_response<'life0, 'async_trait>(
&'life0 self,
input: WriteGetObjectResponseInput
) -> Pin<Box<dyn Future<Output = S3Result<WriteGetObjectResponseOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn write_get_object_response<'life0, 'async_trait>( &'life0 self, input: WriteGetObjectResponseInput ) -> Pin<Box<dyn Future<Output = S3Result<WriteGetObjectResponseOutput>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,
Passes transformed